CREATE TABLE IF NOT EXISTS "PUBLIC"."DASHBOARD_HISTORY"(
    "DASHBOARD_HISTORY_ID" BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "ID" BIGINT NOT NULL,
    "VERSION" BIGINT NOT NULL,
    "NAME" CHARACTER VARYING(255) NOT NULL,
    "DEFAULT_PARAMS" CHARACTER VARYING(2000) NOT NULL,
    "DATE_CREATED" TIMESTAMP NOT NULL,
    "DATE_UPDATED" TIMESTAMP NOT NULL,
    "DATA" CHARACTER LARGE OBJECT,
    "USER_ID" BIGINT,
    "TEAM_ID" BIGINT,
    "CREATOR_ID" BIGINT,
    "TAGS" CHARACTER VARYING(255) NOT NULL,
    "COMMENT" CHARACTER VARYING(255) NOT NULL,
    "PPUBLIC" BOOLEAN NOT NULL
);    

CREATE TABLE IF NOT EXISTS "PUBLIC"."USERS"(
    "ID" BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "ADMIN" BOOLEAN NOT NULL,
    "NAME" CHARACTER VARYING(255) NOT NULL UNIQUE,
    "EMAIL" CHARACTER VARYING(255),
    "DATE_CREATED" TIMESTAMP,
    "DATE_UPDATED" TIMESTAMP,
    "PASSWORD" CHARACTER VARYING(255) NOT NULL,
    "ROLE_TYPE" CHARACTER VARYING(255) NOT NULL,
    "DELETED" BOOLEAN NOT NULL,
    "EMAIL_VERIFIED" BOOLEAN NOT NULL,
    "EMAIL_CODE" CHARACTER VARYING(255) NOT NULL,
    "REG_IP" CHARACTER VARYING(255) NOT NULL,
    "STAR_COUNT" BIGINT NOT NULL,
    "ORIGIN" CHARACTER VARYING(255) NOT NULL,
    "URL" CHARACTER VARYING(255),
    "TWITTER" CHARACTER VARYING(255),
    "LINKEDIN" CHARACTER VARYING(255),
    "BIO" CHARACTER VARYING(255)
);

CREATE TABLE IF NOT EXISTS "PUBLIC"."FAVOURITES"(
    "DASHBOARD_ID" BIGINT NOT NULL,
    "USER_ID" BIGINT NOT NULL
);            


CREATE TABLE IF NOT EXISTS "PUBLIC"."DASHBOARD"(
    "ID"  BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "VERSION" BIGINT NOT NULL,
    "DEFAULT_PARAMS" CHARACTER VARYING(2000) NOT NULL,
    "NAME" CHARACTER VARYING(255) NOT NULL,
    "DATE_CREATED" TIMESTAMP,
    "DATE_UPDATED" TIMESTAMP,
    "TAGS" CHARACTER VARYING(255) NOT NULL,
    "COMMENT" CHARACTER VARYING(255) NOT NULL,
    "PPUBLIC" BOOLEAN NOT NULL,
    "STAR_COUNT" BIGINT NOT NULL,
    "VIEW_COUNT" BIGINT NOT NULL,
    "USER_ID" BIGINT,
    "TEAM_ID" BIGINT,
    "CREATOR_ID" BIGINT,
    "DATA" CHARACTER LARGE OBJECT
);     


CREATE TABLE IF NOT EXISTS "PUBLIC"."REPORT_CONFIG"(
    "ID" BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "VERSION" BIGINT NOT NULL,
    "DATE_CREATED" TIMESTAMP,
    "DATE_UPDATED" TIMESTAMP,
    "URL" CHARACTER VARYING(255) NOT NULL,
    "CRON" CHARACTER VARYING(255) NOT NULL,
    "WIDTH" INTEGER,
    "HEIGHT" INTEGER,
    "SECONDS_DELAY" INTEGER,
    "CREATOR_ID" BIGINT,
    "OWNER_ID" BIGINT NOT NULL,
    "DASH_ID" BIGINT NOT NULL
);      

CREATE TABLE IF NOT EXISTS "PUBLIC"."REPORT_RESULT"(
    "ID" BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "VERSION" BIGINT NOT NULL,
    "DATE_CREATED" TIMESTAMP,
    "DATE_UPDATED" TIMESTAMP,
    "URL" CHARACTER VARYING(255) NOT NULL,
    "REPORT_ID" BIGINT NOT NULL,
    "DASH_ID" BIGINT NOT NULL,
    "DATE_COMPLETED" TIMESTAMP,
    "RESULT" CHARACTER VARYING(255) NOT NULL,
    "LOG" CHARACTER VARYING,
    "HTML" CHARACTER VARYING,
    "SUCCEEDED" BOOLEAN NOT NULL,
    "IMG" BINARY LARGE OBJECT
);        

CREATE TABLE IF NOT EXISTS "PUBLIC"."DATASOURCE"(
    "ID"  BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "QUERY_WRAP_PRE" CHARACTER VARYING(255) NOT NULL,
    "QUERY_WRAP_POST" CHARACTER VARYING(255) NOT NULL,
    "NAME" CHARACTER VARYING(255) NOT NULL UNIQUE,
    "USERNAME" CHARACTER VARYING(255) NOT NULL,
    "PASSWORD" CHARACTER VARYING(255) NOT NULL,
    "HOST" CHARACTER VARYING(255) NOT NULL,
    "PORT" INTEGER NOT NULL,
    "DATABASE" CHARACTER VARYING(255) NOT NULL,
    "JDBC_TYPE" INTEGER NOT NULL,
    "DATE_CREATED" TIMESTAMP,
    "DATE_UPDATED" TIMESTAMP,
    "USER_ID" BIGINT,
    "TEAM_ID" BIGINT,
    "CREATOR_ID" BIGINT,
    "PPUBLIC" BOOLEAN NOT NULL,
    "PROPERTIES" CHARACTER VARYING(255) NOT NULL,
    "WRAP_QUERY" BOOLEAN NOT NULL
);            

CREATE TABLE IF NOT EXISTS "PUBLIC"."USER_TEAM"(
    "ID"  BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "DATE_CREATED" TIMESTAMP,
    "DATE_UPDATED" TIMESTAMP,
    "CREATOR_ID" BIGINT NOT NULL,
    "USER_ID" BIGINT NOT NULL,
    "TEAM_ID" BIGINT NOT NULL,
    "ROLE_TYPE" CHARACTER VARYING(255) NOT NULL,
    "ORIGIN" CHARACTER VARYING(255) NOT NULL
);      

CREATE TABLE IF NOT EXISTS "PUBLIC"."PAGE_VIEW"(
    "ID"  BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "URL" CHARACTER VARYING(500) NOT NULL,
    "PATH" CHARACTER VARYING(255) NOT NULL,
    "SEARCH" CHARACTER VARYING(500) NOT NULL,
    "DATE_CREATED" TIMESTAMP,
    "ANONYMOUS_ID" CHARACTER VARYING(255) NOT NULL,
    "DASH_ID" BIGINT NOT NULL,
    "DASH_NAME" CHARACTER VARYING(255) NOT NULL,
    "USER_ID" CHARACTER VARYING(255)
);   
          
CREATE TABLE IF NOT EXISTS "PUBLIC"."TEAM"(
    "ID"  BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "NAME" CHARACTER VARYING(255) NOT NULL UNIQUE,
    "EMAIL" CHARACTER VARYING(255),
    "DATE_CREATED" TIMESTAMP,
    "DATE_UPDATED" TIMESTAMP,
    "CREATOR_ID" BIGINT NOT NULL,
    "DELETED" BOOLEAN NOT NULL,
    "EMAIL_VERIFIED" BOOLEAN NOT NULL,
    "PPUBLIC" BOOLEAN NOT NULL,
    "STAR_COUNT" BIGINT NOT NULL,
    "URL" CHARACTER VARYING(255),
    "TWITTER" CHARACTER VARYING(255),
    "LINKEDIN" CHARACTER VARYING(255),
    "BIO" CHARACTER VARYING(255)
);        

CREATE TABLE IF NOT EXISTS "PUBLIC"."DASHBOARD_SCREENSHOT"(
    "DASHBOARD_SCREENSHOT_ID"  BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "ID" BIGINT NOT NULL,
    "SCREENSHOT" BINARY LARGE OBJECT
);      

CREATE TABLE IF NOT EXISTS "PUBLIC"."SUBSCRIPTION"(
    "ID" BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "USER_ID" BIGINT NOT NULL,
    "REPORT_ID" BIGINT NOT NULL
);   

CREATE TABLE IF NOT EXISTS "PUBLIC"."EVENT"(
    "ID" BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL PRIMARY KEY,
    "EVENT" CHARACTER VARYING(255) NOT NULL,
    "DATE_CREATED" TIMESTAMP,
    "ANONYMOUS_ID" CHARACTER VARYING(255) NOT NULL,
    "DASH_ID" BIGINT NOT NULL,
    "DASH_NAME" CHARACTER VARYING(255) NOT NULL,
    "USER_ID" CHARACTER VARYING(255)
); 